"""
setup.py for backwards compatibility with older pip versions.
For modern installations, pyproject.toml is used instead.
"""
from setuptools import setup

# Configuration is in pyproject.toml
setup()
